==> apache-iotdb-1.2.2-source-release.zip: apache-iotdb-1.2.2/iotdb-core/node-commons/src/main/java/org/apache/iotdb/commons/path/PathPatternTreeUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.commons.path;

public class PathPatternTreeUtils {
  /**
   * Intersect the pattern tree with the full path prefix tree, and return the intersected pattern
   * tree.
   *
   * @param patternTree any pattern tree
   * @param fullPathPrefixTree the included pattern must be fullPath or prefix pattern(e.g.
   *     root.sg.**)
   * @return the intersected pattern tree
   */
  public static PathPatternTree intersectWithFullPathPrefixTree(
      PathPatternTree patternTree, PathPatternTree fullPathPrefixTree) {
    PathPatternTree result = new PathPatternTree();
    for (PartialPath pathPattern : patternTree.getAllPathPatterns()) {
      for (PartialPath fullPathOrPrefix : fullPathPrefixTree.getAllPathPatterns()) {
        if (fullPathOrPrefix.endWithMultiLevelWildcard()) {
          // prefix
          for (PartialPath temp : pathPattern.intersectWithPrefixPattern(fullPathOrPrefix)) {
            result.appendPathPattern(temp);
          }
        } else {
          // full path
          if (pathPattern.matchFullPath(fullPathOrPrefix)) {
            result.appendPathPattern(fullPathOrPrefix);
          }
        }
      }
    }
    result.constructTree();
    return result;
  }
}

==> apache-iotdb-1.3.2-source-release.zip: apache-iotdb-1.3.2/iotdb-core/node-commons/src/main/java/org/apache/iotdb/commons/path/PathPatternTreeUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.commons.path;

import org.apache.iotdb.commons.schema.SchemaConstant;

public class PathPatternTreeUtils {
  /**
   * Intersect the pattern tree with the full path prefix tree, and return the intersected pattern
   * tree.
   *
   * @param patternTree any pattern tree
   * @param fullPathPrefixTree the included pattern must be fullPath or prefix pattern(e.g.
   *     root.sg.**)
   * @return the intersected pattern tree
   */
  public static PathPatternTree intersectWithFullPathPrefixTree(
      PathPatternTree patternTree, PathPatternTree fullPathPrefixTree) {
    if (SchemaConstant.ALL_MATCH_SCOPE.equals(fullPathPrefixTree)) {
      return patternTree;
    }
    return patternTree.intersectWithFullPathPrefixTree(fullPathPrefixTree);
  }
}
